@@ -96,6 +96,13 @@ def test_val_scratch():
     model.val(data='coco8.yaml', imgsz=32)
 
 
+def test_amp():
+    if torch.cuda.is_available():
+        from ultralytics.yolo.engine.trainer import check_amp
+        model = YOLO(MODEL).model.cuda()
+        assert check_amp(model)
+
+
 def test_train_scratch():
     model = YOLO(CFG)
     model.train(data='coco8.yaml', epochs=1, imgsz=32)
@@ -200,9 +207,9 @@ def test_predict_callback_and_setup():
 def test_result():
     model = YOLO('yolov8n-seg.pt')
     res = model([SOURCE, SOURCE])
-    res[0].cpu().numpy()
     res[0].plot(show_conf=False)
-    print(res[0].path)
+    res[0] = res[0].cpu().numpy()
+    print(res[0].path, res[0].masks.masks)
 
     model = YOLO('yolov8n.pt')
     res = model(SOURCE)
@@ -213,6 +220,3 @@ def test_result():
     res = model(SOURCE)
     res[0].plot()
     print(res[0].path)
-
-
-test_predict_img()
